==> mailman-2.1.b4.tbz: etc/rc.d/mailman.sh <==
#!/bin/sh
#
# mailman    This shell script that starts and stops GNU Mailman.
#
# Copyright (C) 2001,2002 by the Free Software Foundation, Inc.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software 
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# Copy this file to /etc/init.d/ (or /etc/rc.d/init.d/ depending on
# your system) and activate it as such:
#
# On Debian, type "update-rc.d mailman defaults"
# On RedHat, and derivatives, install with "chkconfig --add mailman"
#
# chkconfig: 2345 98 12
# description: Mailman is the GNU Mailing List Manager, a program that \
#              manages electronic mail discussion groups.  For more \
#              on GNU Mailman see http://www.list.org
# processname: mailmanctl
# config: /usr/local/mailman/Mailman/mm_cfg.py
# pidfile: /usr/local/mailman/data/qrunner.pid

PYTHON=/usr/local/bin/python2.2
MAILMANHOME=/usr/local/mailman
MAILMANCTL=$MAILMANHOME/bin/mailmanctl

case "$1" in
'start')
    #rm -f $MAILMANHOME/locks/*
    $PYTHON $MAILMANCTL -s -q start && echo -n ' mailman'
    ;;

'stop')
    $PYTHON $MAILMANCTL -q stop && echo -n ' mailman'
    ;;

'restart')
    $PYTHON $MAILMANCTL -q restart
    ;;
*)
    echo "Usage: `basename $0` {start|stop|restart}" >&2
    exit 64
    ;;

esac
exit 0

==> mailman-2.1.7.tbz: etc/rc.d/mailman.sh <==
#!/bin/sh
#
# mailman    This shell script starts and stops GNU Mailman.
#
# Copyright (C) 2001-2003 by the Free Software Foundation, Inc.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Copy this file to /etc/init.d/ (or /etc/rc.d/init.d/ depending on
# your system) and activate it as such:
#
# On Debian, type "update-rc.d mailman defaults"
# On RedHat, and derivatives, install with "chkconfig --add mailman"
#
# chkconfig: 2345 98 12
# description: Mailman is the GNU Mailing List Manager, a program that \
#              manages electronic mail discussion groups.  For more \
#              on GNU Mailman see http://www.list.org
# processname: mailmanctl
# config: /usr/local/mailman/Mailman/mm_cfg.py
# pidfile: /usr/local/mailman/data/master-qrunner.pid

PYTHON=/usr/local/bin/python
MAILMANHOME=/usr/local/mailman
MAILMANCTL=$MAILMANHOME/bin/mailmanctl

case "$1" in
'start')
    #rm -f $MAILMANHOME/locks/*
    $PYTHON $MAILMANCTL -s -q start && echo -n ' mailman'
    ;;

'stop')
    $PYTHON $MAILMANCTL -q stop && echo -n ' mailman'
    ;;

'restart')
    $PYTHON $MAILMANCTL -q restart
    ;;
*)
    echo "Usage: `basename $0` {start|stop|restart}" >&2
    exit 64
    ;;

esac
exit 0
